@@ -293,6 +293,10 @@ script_websocket.onmessage = (e)=> {
             proStatusElement.setAttribute('key-title', proTitleKeyActive);
 
             proRuntimeElement.style.color = 'green';
+            if(protocolDate.toLocaleDateString() === "31.12.9999"){
+              proRuntimeElement.innerHTML = "";
+              proRuntimeElement.classList.add('mdi','mdi-24px','mdi-infinity');
+            }
         } else {
             console.log(`%c Custom Protokol is inactiv (${script_setting.custom_protocol})`, 'background: #222; color: #ee395b; padding: 1em;');
             proStatusElement.classList.remove('mdi-check-circle');
