@@ -282,7 +282,7 @@ function SelectSessionDel() {
 function RowImg(params) {
     // session.send()
     if(params.length == 0){
-        document.getElementById('pi_retriveSession').innerHTML = `<button key="cli_NoSession" class="uk-button uk-button-primary uk-modal-close"><!--fortsetzen--></button>`;
+        //document.getElementById('pi_retriveSession').innerHTML = `<button key="cli_NoSession" class="uk-button uk-button-primary uk-modal-close"><!--fortsetzen--></button>`;
     }
     fi = 0;
     recID = [];
