@@ -888,7 +888,7 @@ function addField(category) {
             message: `${newField} ${aLangKeys[lang]['sys_exist']}`,
             status: 'warning',
             pos: 'top-right',
-            timeout: 2500
+            timeout: 2500,
         });
         return;
     }
@@ -929,7 +929,72 @@ function saveCostomJSN(){
 }
 
 //END SORT AND EDIT CUSTOM PROTOCOL
+let activeInput = null;
+let isShiftActive = false;
 
+const virtualKey = document.getElementById('simple_keyboard')
+
+function showKeybord (){
+    virtualKey.classList.toggle('hidden')
+}
+
+document.querySelectorAll("input").forEach(input => {
+    input.addEventListener("focus", () => {
+        activeInput = input;
+    });
+});
+
+function virtualKeybord () {
+    document.querySelectorAll("input").forEach(input => {
+        input.addEventListener("focus", () => {
+            activeInput = input;
+        });
+    });
+}
+
+// Tastaturlayouts für Groß-/Kleinschreibung
+const keyboardLayouts = {
+    lowercase: [
+        "1 2 3 4 5 6 7 8 9 0 {bksp}",
+        "q w e r t z u i o p ü +",
+        "a s d f g h j k l ö ä #",
+        "{shift} y x c v b n m - {enter}"
+    ],
+    uppercase: [
+        "! § $ % ( ) = ? ẞ  {bksp}",
+        "Q W E R T Z U I O P Ü",
+        "A S D F G H J K L Ö Ä",
+        "{shift} Y X C V B N M _ {enter}"
+    ]
+};
+
+// Initialisiere die Tastatur
+const Keyboard = new SimpleKeyboard.default({
+    onChange: input => {
+        if (activeInput) {
+            activeInput.value = input;
+        }
+    },
+    onKeyPress: button => {
+        if (button === "{shift}") {
+            isShiftActive = !isShiftActive;
+            Keyboard.setOptions({
+                layout: {
+                    default: isShiftActive ? keyboardLayouts.uppercase : keyboardLayouts.lowercase
+                }
+            });
+        } else if (button === "{bksp}") {
+            if (activeInput) {
+                activeInput.value = activeInput.value.slice(0, -1);
+            }
+        }
+    },
+    layout: {
+        default: keyboardLayouts.lowercase
+    }
+});
+
+showKeybord()
 
 $( document ).ready(function() {
     
